@@ -1,14 +1,15 @@
 #! /usr/lib/veetest/veetest -r
-(revision "A.00.00")
-(date "Wed 10/Apr/1991")
-(component 0 "Context"
+(revision "B.00.00")
+(date "Fri 13/Nov/1992")
+(component 0 "ROOTCONTEXT"
  (name " Curve fit using Regression")
  (interface
  )
  (implementation
-  (trigMode deg)
   (locked no)
-  (component 0 "YPlot"
+  (trigMode deg)
+  (nextID 17)
+  (component 0 "YPLOT"
    (name "XY Trace")
    (interface
     (sequence in)
@@ -55,10 +56,10 @@
    )
    (views
     (icon
-     (iconImage display.icon)
+     (iconImage "display.icon")
     )
     (detail
-     (origin 537 267)
+     (origin 537 262)
      (extent 426 447)
      (displayMode scrollGraph)
      (graphType cartesian)
@@ -66,38 +67,38 @@
      (scale 0
       (name "Y name")
       (domainName "X name")
-      (color 0x909090)
+      (pen 9)
       (show 1)
       (range -50 250 3 linear)
      )
      (domain 0 100 3 linear)
      (trace 0 onScale 0
       (name "data")
-      (color 0xffffff)
+      (pen 1)
       (lineType 3)
       (pointType 1)
      )
      (trace 1 onScale 0
       (name "Exponential")
-      (color 0xccff)
+      (pen 7)
       (lineType 1)
       (pointType 0)
      )
      (trace 2 onScale 0
       (name "Log")
-      (color 0xffaaaa)
+      (pen 6)
       (lineType 1)
       (pointType 0)
      )
      (trace 3 onScale 0
       (name "linear")
-      (color 0xee44)
+      (pen 3)
       (lineType 1)
       (pointType 0)
      )
      (trace 4 onScale 0
       (name "Poly-3")
-      (color 0xffdd00)
+      (pen 4)
       (lineType 1)
       (pointType 0)
      )
@@ -105,7 +106,7 @@
     (active detail)
    )
   )
-  (component 1 "Start"
+  (component 1 "START"
    (interface
     (sequence out)
    )
@@ -113,7 +114,7 @@
    )
    (views
     (icon
-     (origin 36 101)
+     (origin 36 96)
      (extent 69 39)
     )
     (detail
@@ -122,7 +123,7 @@
     (active icon)
    )
   )
-  (component 2 "Context"
+  (component 2 "CONTEXT"
    (name "Random Noise")
    (interface
     (sequence in)
@@ -135,9 +136,10 @@
     )
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "Collector"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "COLLECTOR"
      (interface
       (sequence in)
       (sequence out)
@@ -161,6 +163,7 @@
      (implementation
       (component clearAtPrerun 1)
       (component clearAtActivate 1)
+      (component output1D YES)
      )
      (views
       (icon
@@ -173,7 +176,7 @@
       (active icon)
      )
     )
-    (component 1 "RandomNumber"
+    (component 1 "RANDOMNUMBER"
      (interface
       (sequence in)
       (sequence out)
@@ -199,7 +202,7 @@
       (active detail)
      )
     )
-    (component 2 "ForCount"
+    (component 2 "FORCOUNT"
      (interface
       (sequence in)
       (sequence out)
@@ -216,7 +219,7 @@
       (icon
        (origin 305 138)
        (extent 110 64)
-       (iconImage loop.icon)
+       (iconImage "loop.icon")
       )
       (detail
        (origin 15 193)
@@ -234,7 +237,7 @@
    )
    (views
     (icon
-     (origin 11 158)
+     (origin 11 153)
      (extent 118 25)
     )
     (detail
@@ -259,7 +262,7 @@
        (Point 200 210)
        (Point 200 160)
        (Point 330 160)
-       (Point 330 177)
+       (Point 330 179)
       )
       (connect D0:1 O1:1
        (Point 277 310)
@@ -268,11 +271,12 @@
        (Point 492 240)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active icon)
    )
   )
-  (component 3 "ExitProcess"
+  (component 3 "EXITPROCESS"
    (interface
     (sequence in)
    )
@@ -281,7 +285,7 @@
    )
    (views
     (icon
-     (origin 157 288)
+     (origin 157 283)
      (extent 46 25)
     )
     (detail
@@ -291,7 +295,7 @@
     (active icon)
    )
   )
-  (component 4 "Formula"
+  (component 4 "FORMULA"
    (name "# PTS, Start, Stop + Noise   -->")
    (interface
     (sequence in)
@@ -316,7 +320,7 @@
    )
    (views
     (icon
-     (origin 31 238)
+     (origin 31 233)
      (extent 298 25)
     )
     (detail
@@ -327,7 +331,7 @@
     (active icon)
    )
   )
-  (component 5 "ToFunction"
+  (component 5 "TOFUNCTION"
    (interface
     (sequence in)
     (sequence out)
@@ -352,9 +356,9 @@
    )
    (views
     (icon
-     (origin 371 218)
+     (origin 371 213)
      (extent 118 64)
-     (iconImage build.icon)
+     (iconImage "build.icon")
     )
     (detail
      (origin 12 428)
@@ -363,7 +367,7 @@
     (active icon)
    )
   )
-  (component 6 "Regression"
+  (component 6 "REGRESSION"
    (interface
     (sequence in)
     (sequence out)
@@ -403,7 +407,7 @@
    )
    (views
     (icon
-     (origin 185 393)
+     (origin 185 388)
      (extent 110 34)
     )
     (detail
@@ -414,7 +418,7 @@
     (active icon)
    )
   )
-  (component 7 "TextDisplay"
+  (component 7 "TEXTDISPLAY"
    (name "Goodness of Fit -->")
    (interface
     (sequence in)
@@ -430,7 +434,7 @@
    )
    (views
     (icon
-     (origin 330 418)
+     (origin 330 413)
      (extent 181 25)
     )
     (detail
@@ -440,7 +444,7 @@
     (active icon)
    )
   )
-  (component 8 "Regression"
+  (component 8 "REGRESSION"
    (interface
     (sequence in)
     (sequence out)
@@ -480,7 +484,7 @@
    )
    (views
     (icon
-     (origin 185 563)
+     (origin 185 558)
      (extent 110 34)
     )
     (detail
@@ -491,7 +495,7 @@
     (active icon)
    )
   )
-  (component 9 "Regression"
+  (component 9 "REGRESSION"
    (interface
     (sequence in)
     (sequence out)
@@ -528,7 +532,7 @@
    )
    (views
     (icon
-     (origin 185 483)
+     (origin 185 478)
      (extent 110 34)
     )
     (detail
@@ -538,7 +542,7 @@
     (active icon)
    )
   )
-  (component 10 "Regression"
+  (component 10 "REGRESSION"
    (interface
     (sequence in)
     (sequence out)
@@ -579,7 +583,7 @@
    )
    (views
     (icon
-     (origin 185 643)
+     (origin 185 638)
      (extent 110 34)
     )
     (detail
@@ -590,7 +594,7 @@
     (active icon)
    )
   )
-  (component 11 "TextDisplay"
+  (component 11 "TEXTDISPLAY"
    (name "Goodness of Fit -->")
    (interface
     (sequence in)
@@ -606,7 +610,7 @@
    )
    (views
     (icon
-     (origin 340 688)
+     (origin 340 683)
      (extent 181 25)
     )
     (detail
@@ -616,7 +620,7 @@
     (active icon)
    )
   )
-  (component 12 "TextDisplay"
+  (component 12 "TEXTDISPLAY"
    (name "Goodness of Fit -->")
    (interface
     (sequence in)
@@ -632,7 +636,7 @@
    )
    (views
     (icon
-     (origin 330 598)
+     (origin 330 593)
      (extent 181 25)
     )
     (detail
@@ -642,7 +646,7 @@
     (active icon)
    )
   )
-  (component 13 "TextDisplay"
+  (component 13 "TEXTDISPLAY"
    (name "Goodness of Fit -->")
    (interface
     (sequence in)
@@ -658,7 +662,7 @@
    )
    (views
     (icon
-     (origin 330 518)
+     (origin 330 513)
      (extent 181 25)
     )
     (detail
@@ -668,7 +672,7 @@
     (active icon)
    )
   )
-  (component 14 "Note"
+  (component 14 "NOTE"
    (name "To Operate")
    (interface
    )
@@ -692,9 +696,9 @@
    )
    (views
     (icon
-     (origin 5 288)
+     (origin 5 283)
      (extent 110 64)
-     (iconImage notepad.icon)
+     (iconImage "notepad.icon")
     )
     (detail
      (origin 10 265)
@@ -704,16 +708,17 @@
     (active icon)
    )
   )
-  (component 15 "Context"
+  (component 15 "CONTEXT"
    (name "Press For")
    (interface
     (sequence in)
     (sequence out)
    )
    (implementation
-    (trigMode deg)
     (locked no)
-    (component 0 "IfThenElse"
+    (trigMode deg)
+    (nextID 3)
+    (component 0 "IFTHENELSE"
      (name "!= 0")
      (interface
       (sequence in)
@@ -751,7 +756,7 @@
       (active icon)
      )
     )
-    (component 1 "Toggle"
+    (component 1 "TOGGLE"
      (name "Info About")
      (interface
       (sequence in)
@@ -777,6 +782,7 @@
       (component initializeAtPrerun off)
       (component initializeAtActivate off)
       (component initValue Int32
+       (name "LongInt")
        (datum 0)
       )
      )
@@ -794,17 +800,22 @@
       (active icon)
      )
     )
-    (component 2 "Context"
+    (component 2 "CONTEXT"
      (name "Info About This Example")
      (interface
       (sequence in)
       (sequence out)
      )
      (implementation
-      (trigMode deg)
       (locked no)
-      (component 0 "Note"
+      (trigMode deg)
+      (nextID 2)
+      (component 0 "NOTE"
        (name "NotePad")
+       (description 2 8
+        This notepad is displayed as a Show on Execute
+        panel to present the information to the reader.
+       )
        (interface
        )
        (implementation
@@ -835,10 +846,6 @@
         )
        )
        (views
-        (description 2 9
-         This notepad is displayed as a Show on Execute
-         panel to present the information to the reader.
-        )
         (icon
          (origin 160 185)
          (extent 78 25)
@@ -851,8 +858,17 @@
         (active icon)
        )
       )
-      (component 1 "Confirm"
+      (component 1 "CONFIRM"
        (name "DONE")
+       (description 7 8
+        This tiny "thread" begins running when the 
+        enclosing UserObject is executed.  When the user
+        acknowledges the OK/DONE button, there is nothing
+        left to execute, so the thread ends.  Since there
+        are not other threads running, the User Object
+        is completed and will exit, removing the Show on
+        Execute pop-up display.
+       )
        (interface
         (sequence in)
         (sequence out)
@@ -865,15 +881,6 @@
        (implementation
        )
        (views
-        (description 7 9
-         This tiny "thread" begins running when the 
-         enclosing UserObject is executed.  When the user
-         acknowledges the OK/DONE button, there is nothing
-         left to execute, so the thread ends.  Since there
-         are not other threads running, the User Object
-         is completed and will exit, removing the Show on
-         Execute pop-up display.
-        )
         (icon
          (origin 171 252)
          (extent 58 37)
@@ -918,6 +925,7 @@
        (extent 866 520)
        (configuration
        )
+       (stackingOrder 0 1)
       )
       (active icon)
      )
@@ -934,11 +942,11 @@
      (extent 110 25)
     )
     (panel
-     (origin 201 122)
+     (origin 201 117)
      (extent 319 77)
      (widget 1 icon
       (title off)
-      (origin 303 135)
+      (origin 303 130)
       (extent 114 39)
       (format button)
      )
@@ -964,19 +972,20 @@
        (Point 450 405)
       )
      )
+     (stackingOrder 0 1 2)
     )
     (active panel)
     (active panel)
    )
   )
-  (component 16 "Note"
+  (component 16 "NOTE"
    (name "Warranty Disclaimer")
    (interface
    )
    (implementation
     (component text 4 5
      This example is provided as an illustration
-     "as is", and Hewlett-PackardCompany makes
+     "as is", and Hewlett-Packard Company makes
      no warranty of any kind with regard to this
      example.
     )
@@ -988,7 +997,7 @@
     (detail
      (origin 553 115)
      (extent 415 90)
-     (editing disabled)
+     (editing enabled)
     )
     (active detail)
    )
@@ -1015,11 +1024,11 @@
  )
  (views
   (panel
-   (origin 0 67)
+   (origin 0 62)
    (extent 1024 679)
    (widget 11 detail
     (title on)
-    (origin 269 555)
+    (origin 269 550)
     (extent 219 35)
     (formatter
      (realFormat standard)
@@ -1030,7 +1039,7 @@
    )
    (widget 12 detail
     (title on)
-    (origin 268 475)
+    (origin 268 470)
     (extent 219 35)
     (formatter
      (realFormat standard)
@@ -1041,12 +1050,12 @@
    )
    (widget 13 detail
     (title on)
-    (origin 268 398)
+    (origin 268 393)
     (extent 219 35)
    )
    (widget 7 detail
     (title on)
-    (origin 270 321)
+    (origin 270 316)
     (extent 219 35)
     (formatter
      (realFormat standard)
@@ -1057,29 +1066,29 @@
    )
    (widget 14 detail
     (title on)
-    (origin 65 323)
+    (origin 65 318)
     (extent 191 266)
     (editing disabled)
    )
    (widget 15 panel
     (title on)
-    (origin 62 113)
+    (origin 62 108)
     (extent 189 85)
     (widget 1 icon
      (title off)
-     (origin 103 131)
+     (origin 103 126)
      (extent 114 39)
      (format button)
     )
    )
    (widget 1 icon
     (title off)
-    (origin 270 79)
+    (origin 270 74)
     (extent 214 117)
    )
    (widget 0 detail
     (title on)
-    (origin 498 113)
+    (origin 498 108)
     (extent 478 604)
     (displayMode annotGraph)
     (graphType cartesian)
@@ -1087,169 +1096,171 @@
     (scale 0
      (name "Y name")
      (domainName "X name")
-     (color 0x909090)
+     (pen 9)
      (show 1)
      (range -50 250 3 linear)
     )
     (domain 0 100 3 linear)
     (trace 0 onScale 0
      (name "data")
-     (color 0xffdd00)
+     (pen 4)
      (lineType 1)
      (pointType 2)
     )
     (trace 1 onScale 0
      (name "Exponential")
-     (color 0xccff)
+     (pen 7)
      (lineType 1)
      (pointType 0)
     )
     (trace 2 onScale 0
      (name "Log")
-     (color 0xff0000)
+     (pen 2)
      (lineType 1)
      (pointType 0)
     )
     (trace 3 onScale 0
      (name "linear")
-     (color 0xffaaaa)
+     (pen 6)
      (lineType 1)
      (pointType 0)
     )
     (trace 4 onScale 0
      (name "Poly-3")
-     (color 0xee44)
+     (pen 3)
      (lineType 1)
      (pointType 0)
     )
    )
+   (widget 4 detail
+    (title on)
+    (origin 64 244)
+    (extent 422 28)
+   )
    (widget 16 detail
     (title on)
-    (origin 66 635)
+    (origin 65 629)
     (extent 420 80)
     (editing disabled)
    )
-   (widget 4 detail
-    (title on)
-    (origin 64 249)
-    (extent 422 28)
-   )
   )
   (detail
-   (origin 0 67)
+   (origin 0 62)
    (extent 1002 656)
    (configuration
     (connect D5:1 D0:1
-     (Point 491 250)
-     (Point 510 250)
-     (Point 510 310)
-     (Point 534 310)
+     (Point 491 245)
+     (Point 510 245)
+     (Point 510 305)
+     (Point 534 305)
     )
     (connect D6:1 D0:2
-     (Point 297 400)
-     (Point 534 400)
+     (Point 297 395)
+     (Point 534 395)
     )
     (connect D9:1 D0:3
-     (Point 297 490)
-     (Point 534 490)
+     (Point 297 485)
+     (Point 534 485)
     )
     (connect D8:1 D0:4
-     (Point 297 570)
-     (Point 310 570)
-     (Point 310 580)
-     (Point 534 580)
+     (Point 297 565)
+     (Point 310 565)
+     (Point 310 575)
+     (Point 534 575)
     )
     (connect D10:1 D0:5
-     (Point 297 650)
-     (Point 320 650)
-     (Point 320 670)
-     (Point 534 670)
+     (Point 297 645)
+     (Point 320 645)
+     (Point 320 665)
+     (Point 534 665)
     )
     (connect D1:0 D2:0
-     (Point 70 142)
-     (Point 70 155)
+     (Point 70 137)
+     (Point 70 150)
     )
     (connect D4:0 D3:0
-     (Point 180 265)
-     (Point 180 285)
+     (Point 180 260)
+     (Point 180 280)
     )
     (connect D2:1 D4:1
-     (Point 131 170)
-     (Point 150 170)
-     (Point 150 200)
-     (Point 10 200)
-     (Point 10 250)
-     (Point 28 250)
+     (Point 131 165)
+     (Point 150 165)
+     (Point 150 195)
+     (Point 10 195)
+     (Point 10 245)
+     (Point 28 245)
     )
     (connect D4:1 D5:1
-     (Point 331 250)
-     (Point 368 250)
+     (Point 331 245)
+     (Point 368 245)
     )
     (connect D5:1 D6:1
-     (Point 491 250)
-     (Point 510 250)
-     (Point 510 310)
-     (Point 230 310)
-     (Point 230 370)
-     (Point 170 370)
-     (Point 170 410)
-     (Point 182 410)
+     (Point 491 245)
+     (Point 510 245)
+     (Point 510 305)
+     (Point 230 305)
+     (Point 230 365)
+     (Point 170 365)
+     (Point 170 405)
+     (Point 182 405)
     )
     (connect D6:3 D7:1
-     (Point 297 420)
-     (Point 310 420)
-     (Point 310 430)
-     (Point 327 430)
+     (Point 297 415)
+     (Point 310 415)
+     (Point 310 425)
+     (Point 327 425)
     )
     (connect D5:1 D8:1
-     (Point 491 250)
-     (Point 510 250)
-     (Point 510 310)
-     (Point 230 310)
-     (Point 230 370)
-     (Point 170 370)
-     (Point 170 580)
-     (Point 182 580)
+     (Point 491 245)
+     (Point 510 245)
+     (Point 510 305)
+     (Point 230 305)
+     (Point 230 365)
+     (Point 170 365)
+     (Point 170 575)
+     (Point 182 575)
     )
     (connect D5:1 D9:1
-     (Point 491 250)
-     (Point 510 250)
-     (Point 510 310)
-     (Point 230 310)
-     (Point 230 370)
-     (Point 170 370)
-     (Point 170 500)
-     (Point 182 500)
+     (Point 491 245)
+     (Point 510 245)
+     (Point 510 305)
+     (Point 230 305)
+     (Point 230 365)
+     (Point 170 365)
+     (Point 170 495)
+     (Point 182 495)
     )
     (connect D5:1 D10:1
-     (Point 491 250)
-     (Point 510 250)
-     (Point 510 310)
-     (Point 230 310)
-     (Point 230 370)
-     (Point 170 370)
-     (Point 170 660)
-     (Point 182 660)
+     (Point 491 245)
+     (Point 510 245)
+     (Point 510 305)
+     (Point 230 305)
+     (Point 230 365)
+     (Point 170 365)
+     (Point 170 655)
+     (Point 182 655)
     )
     (connect D10:3 D11:1
-     (Point 297 670)
-     (Point 310 670)
-     (Point 310 700)
-     (Point 337 700)
+     (Point 297 665)
+     (Point 310 665)
+     (Point 310 695)
+     (Point 337 695)
     )
     (connect D8:3 D12:1
-     (Point 297 590)
-     (Point 310 590)
-     (Point 310 610)
-     (Point 327 610)
+     (Point 297 585)
+     (Point 310 585)
+     (Point 310 605)
+     (Point 327 605)
     )
     (connect D9:3 D13:1
-     (Point 297 510)
-     (Point 310 510)
-     (Point 310 530)
-     (Point 327 530)
+     (Point 297 505)
+     (Point 310 505)
+     (Point 310 525)
+     (Point 327 525)
     )
    )
+   (stackingOrder 0 1 2 3 4 5 6 7 8 9
+     10 11 12 13 14 15 16)
   )
   (active panel)
   (active panel)
