@@ -1,6 +1,6 @@
 #! /usr/lib/veetest/veetest -r
 (revision "A.00.01")
-(date "Tue 17/Sep/1991")
+(date "Sun 05/Jan/1992")
 (component 0 "Context"
  (name "String Functions Example")
  (interface
@@ -8,8 +8,305 @@
  (implementation
   (trigMode deg)
   (locked no)
-  (component 0 "LiteralConstant"
-   (name "String")
+  (component 0 "Note"
+   (name "To Operate:")
+   (interface
+   )
+   (implementation
+    (component text 3 5
+     Enter some String data
+     and other parameters,
+     then press RUN.
+    )
+   )
+   (views
+    (icon
+     (extent 110 0)
+     (iconImage "notepad.icon")
+    )
+    (detail
+     (origin 350 111)
+     (extent 221 79)
+     (editing enabled)
+    )
+    (active detail)
+   )
+  )
+  (component 1 "Note"
+   (name "Warranty Disclaimer")
+   (interface
+   )
+   (implementation
+    (component text 4 5
+     This example is provided as an
+     illustration "as is", and Hewlett-Packard
+     Company makes no warranty of any kind
+     with regard to this example.
+    )
+   )
+   (views
+    (icon
+     (extent 181 0)
+    )
+    (detail
+     (origin 592 108)
+     (extent 396 84)
+     (editing enabled)
+    )
+    (active detail)
+   )
+  )
+  (component 2 "TextDisplay"
+   (name "Extracted String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 154 0)
+    )
+    (detail
+     (origin 596 411)
+     (extent 228 38)
+    )
+    (active detail)
+   )
+  )
+  (component 3 "Formula"
+   (name "strFromThru(str,from,thru)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (input 2
+     (type data)
+     (name "from")
+     (lock name constraints)
+    )
+    (input 3
+     (type data)
+     (name "thru")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "substr")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strFromThru(str,from,thru)")
+   )
+   (views
+    (icon
+     (origin 318 413)
+     (extent 244 34)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 4 "TextDisplay"
+   (name "Index of char")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 127 0)
+    )
+    (detail
+     (origin 601 502)
+     (extent 219 37)
+    )
+    (active detail)
+   )
+  )
+  (component 5 "Formula"
+   (name "strPosChar(str,char)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (input 2
+     (type data)
+     (name "char")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "index")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strPosChar(str,char)")
+   )
+   (views
+    (icon
+     (origin 345 508)
+     (extent 190 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 6 "TextDisplay"
+   (name "Number of Chars")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 145 0)
+    )
+    (detail
+     (origin 601 242)
+     (extent 219 37)
+    )
+    (active detail)
+   )
+  )
+  (component 7 "Formula"
+   (name "strLen(str)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strLen(str)")
+   )
+   (views
+    (icon
+     (origin 385 248)
+     (extent 110 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 8 "TextDisplay"
+   (name "Extracted String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 154 0)
+    )
+    (detail
+     (origin 596 321)
+     (extent 228 38)
+    )
+    (active detail)
+   )
+  )
+  (component 9 "Formula"
+   (name "strFromLen(str,from,len)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (input 2
+     (type data)
+     (name "from")
+     (lock name constraints)
+    )
+    (input 3
+     (type data)
+     (name "len")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "substr")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strFromLen(str,from,len)")
+   )
+   (views
+    (icon
+     (origin 327 323)
+     (extent 226 34)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 10 "LiteralConstant"
+   (name "SubStr")
    (interface
     (sequence in)
     (sequence out)
@@ -21,8 +318,8 @@
    )
    (implementation
     (component value Text
-     (name "String")
-     (datum "supercalifragalistic")
+     (name "SubStr")
+     (datum "frag")
     )
     (component autoTrigger off)
     (component initializeAtPrerun off)
@@ -36,49 +333,108 @@
      (extent 78 0)
     )
     (detail
-     (origin 10 266)
+     (origin 10 606)
      (extent 201 28)
     )
     (active detail)
    )
   )
-  (component 1 "Constant"
-   (name "Start Pos.")
-   (subType "Integer")
+  (component 11 "Formula"
+   (name "strPosstr(str1,str2)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str1")
+     (lock name constraints)
+    )
+    (input 2
+     (type data)
+     (name "str2")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "index")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strPosStr(str1,str2)")
+   )
+   (views
+    (icon
+     (origin 345 598)
+     (extent 190 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 12 "TextDisplay"
+   (name "Index of char")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 127 0)
+    )
+    (detail
+     (origin 601 592)
+     (extent 219 37)
+    )
+    (active detail)
+   )
+  )
+  (component 13 "LiteralConstant"
+   (name "Char(s)")
    (interface
     (sequence in)
     (sequence out)
     (output 1
      (type data)
-     (name "Int32")
+     (name "Text")
      (lock name constraints)
     )
    )
    (implementation
-    (component value Int32
-     (name "Start Pos.")
-     (datum 2)
+    (component value Text
+     (name "Char(s)")
+     (datum "e")
     )
     (component autoTrigger off)
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
-    (component initValue Int32
-     (datum 0)
+    (component initValue Text
+     (datum "")
     )
    )
    (views
     (icon
-     (extent 110 0)
+     (extent 78 0)
     )
     (detail
-     (origin 11 345)
-     (extent 199 30)
-     (showFormat int)
+     (origin 10 516)
+     (extent 201 28)
     )
     (active detail)
    )
   )
-  (component 2 "Constant"
+  (component 14 "Constant"
    (name "Num Char")
    (subType "Integer")
    (interface
@@ -114,226 +470,75 @@
     (active detail)
    )
   )
-  (component 3 "TextDisplay"
-   (name "Error Code")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 110 0)
-    )
-    (detail
-     (origin 796 365)
-     (extent 168 30)
-    )
-    (active detail)
-   )
-  )
-  (component 4 "LiteralConstant"
-   (name "Char(s)")
+  (component 15 "Constant"
+   (name "Start Pos.")
+   (subType "Integer")
    (interface
     (sequence in)
     (sequence out)
     (output 1
      (type data)
-     (name "Text")
+     (name "Int32")
      (lock name constraints)
     )
    )
    (implementation
-    (component value Text
-     (name "Char(s)")
-     (datum "e")
+    (component value Int32
+     (name "Start Pos.")
+     (datum 2)
     )
     (component autoTrigger off)
     (component initializeAtPrerun off)
     (component initializeAtActivate off)
-    (component initValue Text
-     (datum "")
+    (component initValue Int32
+     (datum 0)
     )
    )
-   (views
-    (icon
-     (extent 78 0)
-    )
-    (detail
-     (origin 10 516)
-     (extent 201 28)
-    )
-    (active detail)
-   )
-  )
-  (component 5 "TextDisplay"
-   (name "Index of char")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 127 0)
-    )
-    (detail
-     (origin 541 492)
-     (extent 219 37)
-    )
-    (active detail)
-   )
-  )
-  (component 6 "TextDisplay"
-   (name "Error Code")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
    (views
     (icon
      (extent 110 0)
     )
     (detail
-     (origin 799 495)
-     (extent 183 31)
+     (origin 11 325)
+     (extent 199 30)
+     (showFormat int)
     )
     (active detail)
    )
   )
-  (component 7 "LiteralConstant"
-   (name "Reg. Expr.")
+  (component 16 "Formula"
+   (name "strRev(str)")
    (interface
     (sequence in)
     (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
     (output 1
      (type data)
-     (name "Text")
+     (name "Result")
      (lock name constraints)
     )
    )
    (implementation
-    (component value Text
-     (name "Reg. Expr.")
-     (datum ".*\\(li.*li\\)")
-    )
-    (component autoTrigger off)
-    (component initializeAtPrerun off)
-    (component initializeAtActivate off)
-    (component initValue Text
-     (datum "")
-    )
+    (component isLocked yes)
+    (component expr 1 "strRev(str)")
    )
    (views
     (icon
-     (extent 110 0)
+     (origin 375 678)
+     (extent 110 25)
     )
     (detail
-     (origin 10 616)
-     (extent 201 28)
     )
-    (active detail)
+    (terminals on)
+    (active icon)
    )
   )
-  (component 8 "TextDisplay"
-   (name "Match data")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 110 0)
-    )
-    (detail
-     (origin 525 613)
-     (extent 251 34)
-    )
-    (active detail)
-   )
-  )
-  (component 9 "TextDisplay"
-   (name "Error Code")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 110 0)
-    )
-    (detail
-     (origin 812 605)
-     (extent 176 31)
-    )
-    (active detail)
-   )
-  )
-  (component 10 "TextDisplay"
-   (name "Extracted String")
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "Data")
-    )
-   )
-   (implementation
-    (component clearAtPrerun 1)
-    (component clearAtActivate 1)
-   )
-   (views
-    (icon
-     (extent 154 0)
-    )
-    (detail
-     (origin 539 371)
-     (extent 222 38)
-    )
-    (active detail)
-   )
-  )
-  (component 11 "TextDisplay"
-   (name "Number of Chars")
+  (component 17 "TextDisplay"
+   (name "Reversed String")
    (interface
     (sequence in)
     (sequence out)
@@ -351,374 +556,13 @@
      (extent 145 0)
     )
     (detail
-     (origin 541 252)
-     (extent 219 37)
+     (origin 596 671)
+     (extent 228 38)
     )
     (active detail)
    )
   )
-  (component 12 "ShellEscape"
-   (name "length(string)")
-   (description 8 4
-    Length(string) determines the number of chars
-    in the passed string.  If the string is null,
-    the returned length is 0.
-    
-    Note that this function is not the same as the
-    Access Array --> Get Values "Total Size", since
-    the entire string is considered an array element,
-    thus Total Size is always 1.)
-   )
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "string")
-     (requires
-      (datatype Text)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Exit code")
-     (lock name constraints)
-    )
-    (output 2
-     (type data)
-     (name "length")
-     (lock constraints)
-     (optional yes)
-    )
-   )
-   (implementation
-    (attr iopath pipe read "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (attr iopath pipe write "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (procedure
-      WRITE TEXT "expr length \'",string,"\'" EOL
-      READ TEXT length TOKEN EXCLUDE:"\n" COUNT:1
-    )
-    (component shell "none")
-    (component command "/bin/sh -s")
-    (component deathWait "Yes")
-   )
-   (views
-    (icon
-     (origin 292 263)
-     (extent 136 34)
-    )
-    (detail
-     (origin 127 216)
-     (extent 437 129)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 13 "ShellEscape"
-   (name "substr(string,start,num)")
-   (description 14 4
-    Extracts the substring beginning at the "start"
-    character of the given "string", returning at
-    most "num" characters.  The first character of
-    a string is position 1.
-    
-    If a start value less than 1 is given, 1 is
-    assumed.  If the number of characters to extract
-    is greater than the string length, only chars up
-    to the end of string are returned.  If num is 0,
-    no characters are returned, and an Error of 1 s
-    returned.  If a null string is supplied, an Error
-    of 1 is returned, along with a null extracted
-    string.
-    
-   )
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "string")
-     (requires
-      (datatype Text)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "start")
-     (requires
-      (datatype Int32)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (input 3
-     (type data)
-     (name "num")
-     (requires
-      (datatype Int32)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Exit code")
-     (lock name constraints)
-    )
-    (output 2
-     (type data)
-     (name "X")
-     (lock constraints)
-     (optional yes)
-    )
-   )
-   (implementation
-    (attr iopath pipe read "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (attr iopath pipe write "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (procedure
-      WRITE TEXT "expr substr \'",string,"\' ",start," ",num EOL
-      READ TEXT x TOKEN EXCLUDE:"\n" COUNT:1
-    )
-    (component shell "none")
-    (component command "/bin/sh -s")
-    (component deathWait "Yes")
-   )
-   (views
-    (icon
-     (origin 267 343)
-     (extent 226 34)
-    )
-    (detail
-     (origin 80 293)
-     (extent 570 135)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 14 "ShellEscape"
-   (name "index(string,char-set)")
-   (description 5 4
-    Returns the first character position in "string"
-    in which any one of the characters in the char-
-    set is found.  If none of the characters is found
-    in the string or if the string is null, an error
-    code of 1 is returned.
-   )
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "string")
-     (requires
-      (datatype Text)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "chars")
-     (requires
-      (datatype Text)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Exit code")
-     (lock name constraints)
-    )
-    (output 2
-     (type data)
-     (name "X")
-     (lock constraints)
-     (optional yes)
-    )
-   )
-   (implementation
-    (attr iopath pipe read "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (attr iopath pipe write "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (procedure
-      WRITE TEXT "expr index \'",string,"\' \'",chars,"\'" EOL
-      READ TEXT x TOKEN EXCLUDE:"\n" COUNT:1
-    )
-    (component shell "none")
-    (component command "/bin/sh -s")
-    (component deathWait "Yes")
-   )
-   (views
-    (icon
-     (origin 266 483)
-     (extent 208 34)
-    )
-    (detail
-     (origin 155 450)
-     (extent 561 140)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 15 "ShellEscape"
-   (name "match(string,regexp)")
-   (description 18 4
-    Examines "string" for the first match with the
-    Basic Regular Expression (see regexp(5)).  Since
-    all patterns are anchored to the beginning of the
-    string, ^ is not a r.e. metachar.   Because of 
-    this anchoring, regular expression must include
-    all characters beginning with the first; matching
-    only chars in the middle of the string is not
-    directly supported.
-    
-    Normally, match() returns the number of characters
-    that are matched by the regular expression.  An
-    alternative is to return the (sub)set of chars
-    from the match by using the \( and \) metachars.
-    If such a regular expression matches the string,
-    the characters within the \(..\) will be returned
-    instead of the match count.  If no match occurs,
-    0 will still be returned.
-    
-   )
-   (interface
-    (sequence in)
-    (sequence out)
-    (input 1
-     (type data)
-     (name "string")
-     (requires
-      (datatype Text)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (input 2
-     (type data)
-     (name "regexp")
-     (requires
-      (datatype Text)
-      (shape "Scalar")
-     )
-     (optional yes)
-    )
-    (output 1
-     (type data)
-     (name "Exit code")
-     (lock name constraints)
-    )
-    (output 2
-     (type data)
-     (name "X")
-     (lock constraints)
-     (optional yes)
-    )
-   )
-   (implementation
-    (attr iopath pipe read "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (attr iopath pipe write "pipe"
-     (readTerm "\n")
-     (fs " ")
-     (eol "\n")
-     (multiField fullSyntax)
-     (arrayFormat block)
-    )
-    (procedure
-      WRITE TEXT "expr \'",string,"\' : \'",regexp,"\'" EOL
-      READ TEXT x TOKEN EXCLUDE:"\n" COUNT:1
-    )
-    (component shell "none")
-    (component command "/bin/sh -s")
-    (component deathWait "Yes")
-   )
-   (views
-    (icon
-     (origin 275 583)
-     (extent 190 34)
-    )
-    (detail
-     (origin 207 514)
-     (extent 496 132)
-    )
-    (terminals on)
-    (active icon)
-   )
-  )
-  (component 16 "Note"
-   (name "To Operate:")
-   (interface
-   )
-   (implementation
-    (component text 3 5
-     Enter some String data
-     and other parameters,
-     then press RUN.
-    )
-   )
-   (views
-    (icon
-     (extent 110 0)
-     (iconImage "notepad.icon")
-    )
-    (detail
-     (origin 350 121)
-     (extent 221 79)
-     (editing enabled)
-    )
-    (active detail)
-   )
-  )
-  (component 17 "Context"
+  (component 18 "Context"
    (name "Press For")
    (interface
     (sequence in)
@@ -826,33 +670,14 @@
        (interface
        )
        (implementation
-        (component text 27 9
-         PURPOSE:     Provide string manipulation objects using HP-UX "expr" command.
+        (component text 8 9
+         PURPOSE:     Demonstrate use of the Math --> String functions.
          
-         USER INPUT REQUIRED:  Adjust the "string" and other parameters, then press RUN.
-         
-         EXPLANATION: Using the HP-UX escape object to run the "expr" command provides a way to
-                   implement some of the string functions needed to parse text data.  Because
-                   expr is rather good about always sending thing to stdout, the extra tests to
-                   examine the expr exit code is not needed before the READ TOKEN input 
-                   transaction.  Four string function User Objects are illustrated here:
-         
-                        SUBSTR (string, start, num)
-         
-                        INDEX (string, char-set)
-         
-                        LENGTH (string)
-         
-                        MATCH (string, regexp)
-         
-                   Each object has a Show Description that explains the usage and limitations of
-                   the implementation.  The man pages for "expr" may be of additional use to
-                   determine the behavior of these objects for special cases.  
-         
-                   NOTE:  The READ TOKEN EXCLUDE: "\n" operation is used to allow a nil string
-                   to be returned if expr outputs only a "\n" to stdout.  The STRING format would
-                   have skipped over the newline and hung waiting for non-whitespace output!
+         USER INPUT REQUIRED:  Adjust "String" and other parameters, if desired, then press RUN.
          
+         EXPLANATION: Each of the Math String functions are presented with an input string and
+                   other optional parameters as needed.  The resulting strings or character
+                   indexes are displayed.
          
         )
        )
@@ -907,7 +732,6 @@
       (configuration
       )
       (ShowOnExecPanel
-       (origin 0 29)
        (extent 849 571)
        (panel
         (origin 38 164)
@@ -921,7 +745,7 @@
          (title off)
          (origin 49 174)
          (extent 827 463)
-         (editing enabled)
+         (editing disabled)
         )
        )
       )
@@ -952,11 +776,11 @@
      (extent 110 25)
     )
     (panel
-     (origin 11 122)
+     (origin 11 112)
      (extent 319 77)
      (widget 1 icon
       (title off)
-      (origin 113 135)
+      (origin 113 125)
       (extent 114 39)
       (format button)
      )
@@ -987,46 +811,361 @@
     (active panel)
    )
   )
-  (component 18 "Note"
-   (name "Warranty Disclaimer")
+  (component 19 "Formula"
+   (name "strUp(str)")
    (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
    )
    (implementation
-    (component text 4 5
-     This example is provided as an
-     illustration "as is", and Hewlett-Packard
-     Company makes no warranty of any kind
-     with regard to this example.
+    (component isLocked yes)
+    (component expr 1 "strUp(str)")
+   )
+   (views
+    (icon
+     (origin 375 758)
+     (extent 110 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 20 "TextDisplay"
+   (name "Extracted String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 154 0)
+    )
+    (detail
+     (origin 596 841)
+     (extent 228 38)
+    )
+    (active detail)
+   )
+  )
+  (component 21 "Formula"
+   (name "strDown(str)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strDown(str)")
+   )
+   (views
+    (icon
+     (origin 391 848)
+     (extent 118 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 22 "TextDisplay"
+   (name "Extracted String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 154 0)
+    )
+    (detail
+     (origin 595 752)
+     (extent 311 37)
+    )
+    (active detail)
+   )
+  )
+  (component 23 "Formula"
+   (name "Quote the String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "A")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked no)
+    (component expr 1 "\"\\\"\"+a+\"\\\"\"")
+   )
+   (views
+    (icon
+     (origin 197 598)
+     (extent 154 64)
+     (iconImage "formula.icon")
+    )
+    (detail
+     (origin 315 933)
+     (extent 231 35)
+    )
+    (active detail)
+   )
+  )
+  (component 24 "Formula"
+   (name "Quote the String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "A")
+     (optional yes)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked no)
+    (component expr 1 "\"\\\"\"+a+\"\\\"\"")
+   )
+   (views
+    (icon
+     (origin 197 598)
+     (extent 154 64)
+     (iconImage "formula.icon")
+    )
+    (detail
+     (origin 315 1022)
+     (extent 230 36)
+    )
+    (active detail)
+   )
+  )
+  (component 25 "Formula"
+   (name "strTrim(str)")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "str")
+     (lock name constraints)
+    )
+    (output 1
+     (type data)
+     (name "Result")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component isLocked yes)
+    (component expr 1 "strTrim(str)")
+   )
+   (views
+    (icon
+     (origin 91 1028)
+     (extent 118 25)
+    )
+    (detail
+    )
+    (terminals on)
+    (active icon)
+   )
+  )
+  (component 26 "LiteralConstant"
+   (name "String with whitespace")
+   (interface
+    (sequence in)
+    (sequence out)
+    (output 1
+     (type data)
+     (name "Text")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component value Text
+     (name "String with whitespace")
+     (datum "     supercalifragalistic   ")
+    )
+    (component autoTrigger off)
+    (component initializeAtPrerun off)
+    (component initializeAtActivate off)
+    (component initValue Text
+     (datum "")
     )
    )
    (views
     (icon
-     (extent 181 0)
+     (extent 208 0)
     )
     (detail
-     (origin 592 118)
-     (extent 396 84)
-     (editing enabled)
+     (origin 9 846)
+     (extent 282 28)
+    )
+    (active detail)
+   )
+  )
+  (component 27 "TextDisplay"
+   (name "Untrimed String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 145 0)
+    )
+    (detail
+     (origin 598 932)
+     (extent 284 36)
+    )
+    (active detail)
+   )
+  )
+  (component 28 "TextDisplay"
+   (name "Trimed String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (input 1
+     (type data)
+     (name "Data")
+    )
+   )
+   (implementation
+    (component clearAtPrerun 1)
+    (component clearAtActivate 1)
+   )
+   (views
+    (icon
+     (extent 127 0)
+    )
+    (detail
+     (origin 593 1021)
+     (extent 294 38)
+    )
+    (active detail)
+   )
+  )
+  (component 29 "LiteralConstant"
+   (name "String")
+   (interface
+    (sequence in)
+    (sequence out)
+    (output 1
+     (type data)
+     (name "Text")
+     (lock name constraints)
+    )
+   )
+   (implementation
+    (component value Text
+     (name "String")
+     (datum "supercalifragalistic")
+    )
+    (component autoTrigger off)
+    (component initializeAtPrerun off)
+    (component initializeAtActivate off)
+    (component initValue Text
+     (datum "")
+    )
+   )
+   (views
+    (icon
+     (extent 78 0)
+    )
+    (detail
+     (origin 10 236)
+     (extent 201 28)
     )
     (active detail)
    )
   )
   (configuration
-   (connect D13:1 D3:1)
-   (connect D14:2 D5:1)
-   (connect D14:1 D6:1)
-   (connect D15:2 D8:1)
-   (connect D15:1 D9:1)
-   (connect D13:2 D10:1)
-   (connect D12:2 D11:1)
-   (connect D0:1 D12:1)
-   (connect D0:1 D13:1)
-   (connect D1:1 D13:2)
-   (connect D2:1 D13:3)
-   (connect D0:1 D14:1)
-   (connect D4:1 D14:2)
-   (connect D0:1 D15:1)
-   (connect D7:1 D15:2)
+   (connect D3:1 D2:1)
+   (connect D29:1 D3:1)
+   (connect D15:1 D3:2)
+   (connect D14:1 D3:3)
+   (connect D5:1 D4:1)
+   (connect D29:1 D5:1)
+   (connect D13:1 D5:2)
+   (connect D7:1 D6:1)
+   (connect D29:1 D7:1)
+   (connect D9:1 D8:1)
+   (connect D29:1 D9:1)
+   (connect D15:1 D9:2)
+   (connect D14:1 D9:3)
+   (connect D29:1 D11:1)
+   (connect D10:1 D11:2)
+   (connect D11:1 D12:1)
+   (connect D29:1 D16:1)
+   (connect D16:1 D17:1)
+   (connect D29:1 D19:1)
+   (connect D21:1 D20:1)
+   (connect D29:1 D21:1)
+   (connect D19:1 D22:1)
+   (connect D26:1 D23:1)
+   (connect D25:1 D24:1)
+   (connect D26:1 D25:1)
+   (connect D23:1 D27:1)
+   (connect D24:1 D28:1)
   )
  )
  (views
@@ -1034,99 +1173,173 @@
    (origin 0 67)
    (extent 1004 664)
    (configuration
-    (connect D13:1 D3:1
-     (Point 495 350)
-     (Point 510 350)
-     (Point 510 320)
-     (Point 770 320)
-     (Point 770 380)
-     (Point 793 380)
+    (connect D3:1 D2:1
+     (Point 564 430)
+     (Point 593 430)
     )
-    (connect D14:2 D5:1
-     (Point 476 510)
-     (Point 538 510)
+    (connect D29:1 D3:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 310 330)
+     (Point 310 420)
+     (Point 315 420)
     )
-    (connect D14:1 D6:1
-     (Point 476 490)
-     (Point 490 490)
-     (Point 490 440)
-     (Point 780 440)
-     (Point 780 510)
-     (Point 796 510)
+    (connect D15:1 D3:2
+     (Point 212 340)
+     (Point 290 340)
+     (Point 290 430)
+     (Point 315 430)
     )
-    (connect D15:2 D8:1
-     (Point 467 610)
-     (Point 480 610)
-     (Point 480 630)
-     (Point 522 630)
-    )
-    (connect D15:1 D9:1
-     (Point 467 590)
-     (Point 480 590)
-     (Point 480 560)
-     (Point 790 560)
-     (Point 790 620)
-     (Point 809 620)
-    )
-    (connect D13:2 D10:1
-     (Point 495 370)
-     (Point 510 370)
-     (Point 510 390)
-     (Point 536 390)
-    )
-    (connect D12:2 D11:1
-     (Point 430 290)
-     (Point 450 290)
-     (Point 450 270)
-     (Point 538 270)
-    )
-    (connect D0:1 D12:1
-     (Point 213 280)
-     (Point 289 280)
-    )
-    (connect D0:1 D13:1
-     (Point 213 280)
-     (Point 230 280)
-     (Point 230 350)
-     (Point 264 350)
-    )
-    (connect D1:1 D13:2
-     (Point 212 360)
-     (Point 264 360)
-    )
-    (connect D2:1 D13:3
+    (connect D14:1 D3:3
      (Point 211 440)
-     (Point 230 440)
-     (Point 230 370)
-     (Point 264 370)
+     (Point 315 440)
     )
-    (connect D0:1 D14:1
-     (Point 213 280)
-     (Point 230 280)
-     (Point 230 350)
-     (Point 240 350)
-     (Point 240 490)
-     (Point 263 490)
+    (connect D5:1 D4:1
+     (Point 537 520)
+     (Point 598 520)
     )
-    (connect D4:1 D14:2
+    (connect D29:1 D5:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 310 330)
+     (Point 310 390)
+     (Point 330 390)
+     (Point 330 510)
+     (Point 342 510)
+    )
+    (connect D13:1 D5:2
      (Point 213 530)
-     (Point 230 530)
-     (Point 230 510)
-     (Point 263 510)
+     (Point 342 530)
     )
-    (connect D0:1 D15:1
-     (Point 213 280)
-     (Point 230 280)
-     (Point 230 350)
-     (Point 240 350)
-     (Point 240 590)
-     (Point 272 590)
+    (connect D7:1 D6:1
+     (Point 497 260)
+     (Point 598 260)
     )
-    (connect D7:1 D15:2
-     (Point 213 630)
-     (Point 230 630)
-     (Point 230 610)
-     (Point 272 610)
+    (connect D29:1 D7:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 260)
+     (Point 382 260)
+    )
+    (connect D9:1 D8:1
+     (Point 555 340)
+     (Point 593 340)
+    )
+    (connect D29:1 D9:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 324 330)
+    )
+    (connect D15:1 D9:2
+     (Point 212 340)
+     (Point 324 340)
+    )
+    (connect D14:1 D9:3
+     (Point 211 440)
+     (Point 300 440)
+     (Point 300 350)
+     (Point 324 350)
+    )
+    (connect D29:1 D11:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 310 330)
+     (Point 310 390)
+     (Point 330 390)
+     (Point 330 600)
+     (Point 342 600)
+    )
+    (connect D10:1 D11:2
+     (Point 213 620)
+     (Point 342 620)
+    )
+    (connect D11:1 D12:1
+     (Point 537 610)
+     (Point 598 610)
+    )
+    (connect D29:1 D16:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 310 330)
+     (Point 310 390)
+     (Point 330 390)
+     (Point 330 610)
+     (Point 350 610)
+     (Point 350 690)
+     (Point 372 690)
+    )
+    (connect D16:1 D17:1
+     (Point 487 690)
+     (Point 593 690)
+    )
+    (connect D29:1 D19:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 310 330)
+     (Point 310 390)
+     (Point 330 390)
+     (Point 330 610)
+     (Point 350 610)
+     (Point 350 770)
+     (Point 372 770)
+    )
+    (connect D21:1 D20:1
+     (Point 511 860)
+     (Point 593 860)
+    )
+    (connect D29:1 D21:1
+     (Point 213 250)
+     (Point 230 250)
+     (Point 230 330)
+     (Point 310 330)
+     (Point 310 390)
+     (Point 330 390)
+     (Point 330 610)
+     (Point 350 610)
+     (Point 350 770)
+     (Point 360 770)
+     (Point 360 800)
+     (Point 370 800)
+     (Point 370 860)
+     (Point 388 860)
+    )
+    (connect D19:1 D22:1
+     (Point 487 770)
+     (Point 592 770)
+    )
+    (connect D26:1 D23:1
+     (Point 293 860)
+     (Point 300 860)
+     (Point 300 900)
+     (Point 290 900)
+     (Point 290 950)
+     (Point 312 950)
+    )
+    (connect D25:1 D24:1
+     (Point 211 1040)
+     (Point 312 1040)
+    )
+    (connect D26:1 D25:1
+     (Point 293 860)
+     (Point 300 860)
+     (Point 300 900)
+     (Point 70 900)
+     (Point 70 1040)
+     (Point 88 1040)
+    )
+    (connect D23:1 D27:1
+     (Point 548 950)
+     (Point 595 950)
+    )
+    (connect D24:1 D28:1
+     (Point 547 1040)
+     (Point 590 1040)
     )
    )
   )
